var group___overlays =
[
    [ "Ogre::BorderPanelOverlayElement", "class_ogre_1_1_border_panel_overlay_element.html", [
      [ "BorderPanelOverlayElement", "class_ogre_1_1_border_panel_overlay_element.html#a7d44bfd5ed63179395fb90ac62e73870", null ],
      [ "~BorderPanelOverlayElement", "class_ogre_1_1_border_panel_overlay_element.html#a8508eefdf3913b80de4cd99bce987583", null ],
      [ "initialise", "class_ogre_1_1_border_panel_overlay_element.html#a604bff2b48811c8a552683d192c9acee", null ],
      [ "_releaseManualHardwareResources", "class_ogre_1_1_border_panel_overlay_element.html#a73683b1a47b87e93c97d0845a68995a2", null ],
      [ "_restoreManualHardwareResources", "class_ogre_1_1_border_panel_overlay_element.html#a510efae45928a052439f6e5858fbd02c", null ],
      [ "getTypeName", "class_ogre_1_1_border_panel_overlay_element.html#a8cfa741f2d232c8ea02fb5c382e2a79f", null ],
      [ "setBorderSize", "class_ogre_1_1_border_panel_overlay_element.html#a695b0d43274bccc1bdb6d99d75c96b50", null ],
      [ "setBorderSize", "class_ogre_1_1_border_panel_overlay_element.html#ac35895cec71bd39e65c689ac2cea2ddc", null ],
      [ "setBorderSize", "class_ogre_1_1_border_panel_overlay_element.html#add65c1e4bb978ed2bb8439e6b7d24e69", null ],
      [ "getLeftBorderSize", "class_ogre_1_1_border_panel_overlay_element.html#abcbfe3bb9647ffef0d6f60c76bcacecd", null ],
      [ "getRightBorderSize", "class_ogre_1_1_border_panel_overlay_element.html#a7f353279eeebc74cb43cae1d1b6ef344", null ],
      [ "getTopBorderSize", "class_ogre_1_1_border_panel_overlay_element.html#adddbb68811e8b8a63859e96621adcd66", null ],
      [ "getBottomBorderSize", "class_ogre_1_1_border_panel_overlay_element.html#a3477f4afc62d5bbd5f73017c210ac20a", null ],
      [ "setLeftBorderUV", "class_ogre_1_1_border_panel_overlay_element.html#a54f9496555af63e3370a994a4404c1a1", null ],
      [ "setRightBorderUV", "class_ogre_1_1_border_panel_overlay_element.html#a672f841a77af2aba6bfdd5a7b7775ef3", null ],
      [ "setTopBorderUV", "class_ogre_1_1_border_panel_overlay_element.html#ab9b5d5d6d9d243d1ab16d0e67bf852cb", null ],
      [ "setBottomBorderUV", "class_ogre_1_1_border_panel_overlay_element.html#a0caeaa1d1379dec4133849d2c91e258e", null ],
      [ "setTopLeftBorderUV", "class_ogre_1_1_border_panel_overlay_element.html#a1cb930e3203523e799bab77cc484f589", null ],
      [ "setTopRightBorderUV", "class_ogre_1_1_border_panel_overlay_element.html#acc97506b185eead9023153c1d30a5526", null ],
      [ "setBottomLeftBorderUV", "class_ogre_1_1_border_panel_overlay_element.html#ad54e4d97854db5240b975cf8fed0095b", null ],
      [ "setBottomRightBorderUV", "class_ogre_1_1_border_panel_overlay_element.html#a6fc22281774852483db4f1a4f20fd279", null ],
      [ "getLeftBorderUVString", "class_ogre_1_1_border_panel_overlay_element.html#ab6db214eaba51905f6229229b4769c2b", null ],
      [ "getRightBorderUVString", "class_ogre_1_1_border_panel_overlay_element.html#a1abfd6cb3ac45d219cab0c842045c06a", null ],
      [ "getTopBorderUVString", "class_ogre_1_1_border_panel_overlay_element.html#a61c0227c271d8d263225d141dbf8fcdd", null ],
      [ "getBottomBorderUVString", "class_ogre_1_1_border_panel_overlay_element.html#a86c397a83bbad466e552a4c6c7f36d02", null ],
      [ "getTopLeftBorderUVString", "class_ogre_1_1_border_panel_overlay_element.html#ad575439d610670909df306142f1e7119", null ],
      [ "getTopRightBorderUVString", "class_ogre_1_1_border_panel_overlay_element.html#a00b0ec54310848d495c630b7a010d748", null ],
      [ "getBottomLeftBorderUVString", "class_ogre_1_1_border_panel_overlay_element.html#adea6e2ab48aaeb939e8d531addd16d48", null ],
      [ "getBottomRightBorderUVString", "class_ogre_1_1_border_panel_overlay_element.html#ae8c268cd2a81b881542959121c2ad838", null ],
      [ "setBorderMaterialName", "class_ogre_1_1_border_panel_overlay_element.html#a9e2803be1666c04fe2447b97586ef891", null ],
      [ "getBorderMaterialName", "class_ogre_1_1_border_panel_overlay_element.html#ae2b8f950b0cdfce3dfe71d780612da16", null ],
      [ "_updateRenderQueue", "class_ogre_1_1_border_panel_overlay_element.html#aa1f15915438b05491cb3c1190970c17b", null ],
      [ "visitRenderables", "class_ogre_1_1_border_panel_overlay_element.html#a3e872edbeda111745671ff23e982cf50", null ],
      [ "setMetricsMode", "class_ogre_1_1_border_panel_overlay_element.html#a0b05fd3236fbf478dfd59b39938e6202", null ],
      [ "_update", "class_ogre_1_1_border_panel_overlay_element.html#a4621f59d225705e3329a479b1c315828", null ],
      [ "BorderRenderable", "class_ogre_1_1_border_panel_overlay_element.html#a34cbfdb610c9f91d01c1b4adff0844ab", null ]
    ] ],
    [ "Ogre::BorderRenderable", "class_ogre_1_1_border_renderable.html", [
      [ "BorderRenderable", "class_ogre_1_1_border_renderable.html#a70ce2657189a442f5a5b550ef532551c", null ],
      [ "getMaterial", "class_ogre_1_1_border_renderable.html#abbc6d22e607c2e23ae1287b160f4cc35", null ],
      [ "getRenderOperation", "class_ogre_1_1_border_renderable.html#abfd19d50ad996de0aad08c7507290d66", null ],
      [ "getWorldTransforms", "class_ogre_1_1_border_renderable.html#a3d3a17b13761955a65a7020b0c08656f", null ],
      [ "getNumWorldTransforms", "class_ogre_1_1_border_renderable.html#a8897febc0d403fa7896a9b81295e79ec", null ],
      [ "getSquaredViewDepth", "class_ogre_1_1_border_renderable.html#a64c0ff7a486e3700177efe0d5a7c19bd", null ],
      [ "getLights", "class_ogre_1_1_border_renderable.html#aea19589c12edc7ed317fe6a5e259fde8", null ]
    ] ],
    [ "Ogre::Font", "class_ogre_1_1_font.html", [
      [ "CodePoint", "class_ogre_1_1_font.html#aaaa89c1bd6898818423e9ba89502cab3", null ],
      [ "UVRect", "class_ogre_1_1_font.html#a9bdff138015537e6245b4fa016c37d52", null ],
      [ "CodePointRange", "class_ogre_1_1_font.html#aa455a399457bd458852555c696b28f6a", null ],
      [ "CodePointRangeList", "class_ogre_1_1_font.html#a3b754bb7b6d6b9be27d76d7c3a70fc7e", null ],
      [ "Font", "class_ogre_1_1_font.html#a9915203be62b8bd2feda436cc9f08cb0", null ],
      [ "~Font", "class_ogre_1_1_font.html#a02642b36387d7ffd80e164ce1fac4591", null ],
      [ "setType", "class_ogre_1_1_font.html#ab89abe298177153acda383de2d7823ca", null ],
      [ "getType", "class_ogre_1_1_font.html#a1248de6416ef53ce06eaf69bbb20a576", null ],
      [ "setSource", "class_ogre_1_1_font.html#a08e9fef8b8196c28d928c690964fc031", null ],
      [ "getSource", "class_ogre_1_1_font.html#a72c15459c7101517430c046bfa653702", null ],
      [ "setTrueTypeSize", "class_ogre_1_1_font.html#a242776c92b41e51d0dbce17ba9fec747", null ],
      [ "setTrueTypeResolution", "class_ogre_1_1_font.html#abfa4659b19ef3052676ccf8a64181e6f", null ],
      [ "getTrueTypeSize", "class_ogre_1_1_font.html#ad68729fd75b27236a4174a5e5013c448", null ],
      [ "getTrueTypeResolution", "class_ogre_1_1_font.html#adfdd689e89e023ae144207da8b82487a", null ],
      [ "getTrueTypeMaxBearingY", "class_ogre_1_1_font.html#a68ba192b84cc956d76b5d5f463b2f6b2", null ],
      [ "getGlyphTexCoords", "class_ogre_1_1_font.html#afc4eca7ce9f131fc7ad7b55cfd67e3a8", null ],
      [ "setGlyphInfoFromTexCoords", "class_ogre_1_1_font.html#add35224e7d0fe9615222944ea17cde13", null ],
      [ "setGlyphInfo", "class_ogre_1_1_font.html#a47a7dce0f5dc507a7e95b9a86f1be869", null ],
      [ "getGlyphAspectRatio", "class_ogre_1_1_font.html#aab93220342ee23ecbc16d8b30209d93b", null ],
      [ "setGlyphAspectRatio", "class_ogre_1_1_font.html#aa80b463afd8a361e240a5a6856e892e3", null ],
      [ "getGlyphInfo", "class_ogre_1_1_font.html#ac550d4abfd2c2a61edf2c1ad8718afc6", null ],
      [ "addCodePointRange", "class_ogre_1_1_font.html#ac2c1fba5ad2d610ecc78b1e1a6a1b8dc", null ],
      [ "clearCodePointRanges", "class_ogre_1_1_font.html#aff75a40e8ca00a64f19c265e90c61733", null ],
      [ "getCodePointRangeList", "class_ogre_1_1_font.html#a847b5fa1668cee1943651d3bb496f243", null ],
      [ "addMergeFont", "class_ogre_1_1_font.html#a87ce3d81e9b9b53479faa83c1d29c1bb", null ],
      [ "getMergeFontList", "class_ogre_1_1_font.html#ac89f41cb59be64a896776e1b2cd307f4", null ],
      [ "getMaterial", "class_ogre_1_1_font.html#a7b1206935984cda27994ec766dae3f22", null ],
      [ "putText", "class_ogre_1_1_font.html#ac78d744eddeeaef4c01a078f9c3c9119", null ],
      [ "setAntialiasColour", "class_ogre_1_1_font.html#a6ca4172a3f554f07752997b1a25278c0", null ],
      [ "getAntialiasColour", "class_ogre_1_1_font.html#a278117d7414d69dbaed6e7290e842991", null ],
      [ "loadResource", "class_ogre_1_1_font.html#a7d54a57f586af8b040b4e2d3481aaa35", null ],
      [ "_setMaterial", "class_ogre_1_1_font.html#a44e60ba33fb4a583d0239cc5cc9c849f", null ],
      [ "ImGuiOverlay", "class_ogre_1_1_font.html#a837ff11c4d56b5bfd81ffe17c73d92c0", null ]
    ] ],
    [ "Ogre::FontManager", "class_ogre_1_1_font_manager.html", [
      [ "FontManager", "class_ogre_1_1_font_manager.html#a159ba6550b0c2731768db9df66472d19", null ],
      [ "~FontManager", "class_ogre_1_1_font_manager.html#af5a0d804aaaa961248f0bc4ae92ccad5", null ],
      [ "create", "class_ogre_1_1_font_manager.html#ad75e17a4f44f40172e5b458e17d4e4bb", null ],
      [ "getByName", "class_ogre_1_1_font_manager.html#a48cb5b5c89b9e3b9b5c15f9dbf8b9256", null ],
      [ "getSingleton", "class_ogre_1_1_font_manager.html#a7953d419aa5a23ed8c434c37065c4cc5", null ],
      [ "getSingletonPtr", "class_ogre_1_1_font_manager.html#af8c3a7f195076706aaed7707e56d5fa0", null ]
    ] ],
    [ "Ogre::GlyphInfo", "struct_ogre_1_1_glyph_info.html", [
      [ "CodePoint", "struct_ogre_1_1_glyph_info.html#aad869b5e07f3135d09d5ff274e588560", null ],
      [ "UVRect", "struct_ogre_1_1_glyph_info.html#a1cd2479f010df597c523081d2d265b0b", null ],
      [ "codePoint", "struct_ogre_1_1_glyph_info.html#a44d4133e5bc5d9dbe59e062dea40daca", null ],
      [ "uvRect", "struct_ogre_1_1_glyph_info.html#a84b183865a26dd978207ade16075f075", null ],
      [ "aspectRatio", "struct_ogre_1_1_glyph_info.html#a21118e6f23f439e16136ed6473235c7b", null ],
      [ "bearing", "struct_ogre_1_1_glyph_info.html#a379cd258ab2dafb4dd5c8f200975be58", null ],
      [ "advance", "struct_ogre_1_1_glyph_info.html#a0e4668bd868d64c871da6b3941b343d4", null ]
    ] ],
    [ "Ogre::Overlay", "class_ogre_1_1_overlay.html", [
      [ "OverlayContainerList", "class_ogre_1_1_overlay.html#a8f3f648a05816f72743c966c51e948dd", null ],
      [ "Overlay", "class_ogre_1_1_overlay.html#a8d6c54081ea142edf528d4253f32a913", null ],
      [ "~Overlay", "class_ogre_1_1_overlay.html#a5a4051af0e9d239f4cb3d03f092565c3", null ],
      [ "getChild", "class_ogre_1_1_overlay.html#ab16be0edf1c07b6b55f3a2807ad15a88", null ],
      [ "getName", "class_ogre_1_1_overlay.html#aa812682525835dbada2eaf758e53007d", null ],
      [ "setZOrder", "class_ogre_1_1_overlay.html#a5d8481d5fa0990846e53345f1a1cc705", null ],
      [ "getZOrder", "class_ogre_1_1_overlay.html#a27113e2d2a11d4a25b39de408949ac5f", null ],
      [ "isVisible", "class_ogre_1_1_overlay.html#a67425b4b8e3b9e614b498b40c8ada39c", null ],
      [ "isInitialised", "class_ogre_1_1_overlay.html#a40e4504c4421065e1ef7e5ddc78b8444", null ],
      [ "show", "class_ogre_1_1_overlay.html#a3c565f3e5cf61f43fa33542d713e8ccf", null ],
      [ "hide", "class_ogre_1_1_overlay.html#ab210b07a317329bb66df4e674de2a367", null ],
      [ "setVisible", "class_ogre_1_1_overlay.html#a32bb912164310b60164c1dbd09460743", null ],
      [ "add2D", "class_ogre_1_1_overlay.html#a702b15ebaa6d3f8dbb2918500b76c9f0", null ],
      [ "remove2D", "class_ogre_1_1_overlay.html#a5c6182483591872da63ac4cea94671af", null ],
      [ "add3D", "class_ogre_1_1_overlay.html#a296d54af42cc05fddd20e07b5209ab1a", null ],
      [ "remove3D", "class_ogre_1_1_overlay.html#a2ff5331b691cd4f07ee66e63f237baef", null ],
      [ "clear", "class_ogre_1_1_overlay.html#a81c8a84fa283a0341a8c14b6c8168ccb", null ],
      [ "setScroll", "class_ogre_1_1_overlay.html#ae268ad3250bac5058c6d08e00c060289", null ],
      [ "getScrollX", "class_ogre_1_1_overlay.html#aa3b4520fdfd5eb8841ced874e470c4b4", null ],
      [ "getScrollY", "class_ogre_1_1_overlay.html#a3476e577f32a23de48954723d6d2cfcd", null ],
      [ "scroll", "class_ogre_1_1_overlay.html#ae07b1a57498aad0299f0781b09ca9b39", null ],
      [ "setRotate", "class_ogre_1_1_overlay.html#a69d5f4c12c15f00efc7818d201e02e86", null ],
      [ "getRotate", "class_ogre_1_1_overlay.html#ac7e879432998665fc63c2a7d4fce56fe", null ],
      [ "rotate", "class_ogre_1_1_overlay.html#a8282553a59253170ddd0488ab7179792", null ],
      [ "setScale", "class_ogre_1_1_overlay.html#adea3b88baa3697a657e7b5785f0ffedb", null ],
      [ "getScaleX", "class_ogre_1_1_overlay.html#aa9b73c92c3a8e4ff41c65be87d545de6", null ],
      [ "getScaleY", "class_ogre_1_1_overlay.html#a5263af45959efb44ed9f9fdb96cecc14", null ],
      [ "_getWorldTransforms", "class_ogre_1_1_overlay.html#a306fcb0e15b270f7cd1c436fbb3b7b54", null ],
      [ "_findVisibleObjects", "class_ogre_1_1_overlay.html#a1fd9ee89f0d23fee86da33f8210b8e08", null ],
      [ "findElementAt", "class_ogre_1_1_overlay.html#ad3f4601fd9fa23b131937a12ab1e6370", null ],
      [ "get2DElements", "class_ogre_1_1_overlay.html#aa4e92bdffc197ccef962d6d4ed1c54ac", null ],
      [ "getOrigin", "class_ogre_1_1_overlay.html#a99c52c21ab9a19fe1f2f51c9f35c1ecf", null ],
      [ "_notifyOrigin", "class_ogre_1_1_overlay.html#ae48bf2a6596b514f95e9d3a437d8e1e0", null ]
    ] ],
    [ "Ogre::OverlayContainer", "class_ogre_1_1_overlay_container.html", [
      [ "ChildMap", "class_ogre_1_1_overlay_container.html#a774a54c9ca32f2107a1a391ca2439862", null ],
      [ "ChildIterator", "class_ogre_1_1_overlay_container.html#aab02a8f87528fb846039ef718b4d3ba8", null ],
      [ "ChildContainerMap", "class_ogre_1_1_overlay_container.html#a9656b67c4beb90b991ac1595731f7143", null ],
      [ "ChildContainerIterator", "class_ogre_1_1_overlay_container.html#a000e571565ca93dc4ec617a32f632946", null ],
      [ "OverlayContainer", "class_ogre_1_1_overlay_container.html#a0f09017210064bf2fc19066e01f002d1", null ],
      [ "~OverlayContainer", "class_ogre_1_1_overlay_container.html#a3cd4e551ef0573d2158e14aecf94000f", null ],
      [ "addChild", "class_ogre_1_1_overlay_container.html#aa9eec8f6dca98ac61766fc4785b84661", null ],
      [ "addChildImpl", "class_ogre_1_1_overlay_container.html#ac3fe3b72570a82f97bd89032ba8ddd49", null ],
      [ "addChildImpl", "class_ogre_1_1_overlay_container.html#ad3694ec31ad22357270320457e6409a8", null ],
      [ "removeChild", "class_ogre_1_1_overlay_container.html#ab5e6dad5b67266583e13ad2374d0d74f", null ],
      [ "getChild", "class_ogre_1_1_overlay_container.html#a8aeaf008e0b9df8b76d5a90e56fd48f9", null ],
      [ "initialise", "class_ogre_1_1_overlay_container.html#abb4bcfd4e4059aa85c9d1023ce0bf9e3", null ],
      [ "_addChild", "class_ogre_1_1_overlay_container.html#a1b22eddee9083be54a60c09b3a129e9d", null ],
      [ "_removeChild", "class_ogre_1_1_overlay_container.html#a1c4711038030d7464ca3c2b60c380175", null ],
      [ "_removeChild", "class_ogre_1_1_overlay_container.html#a8453a3a1a55f906b8add0878233b1340", null ],
      [ "getChildren", "class_ogre_1_1_overlay_container.html#a1c1993e26161d58155b2590bbdfb7be7", null ],
      [ "getChildIterator", "class_ogre_1_1_overlay_container.html#aef91545671c664dcd0511075ac309d36", null ],
      [ "getChildContainerIterator", "class_ogre_1_1_overlay_container.html#a90e2ac9ae2779b4045c31a84025e8dc4", null ],
      [ "_positionsOutOfDate", "class_ogre_1_1_overlay_container.html#a037458a7f61d67c369740075fd225577", null ],
      [ "_update", "class_ogre_1_1_overlay_container.html#aa010e01a768f07d5c13fe8cd01b4c0d5", null ],
      [ "_notifyZOrder", "class_ogre_1_1_overlay_container.html#affbfdd1b74d6dec7be1a48110c4d2ab6", null ],
      [ "_notifyViewport", "class_ogre_1_1_overlay_container.html#a432ba08f449e7e8e3c918fc14a176ff4", null ],
      [ "_notifyWorldTransforms", "class_ogre_1_1_overlay_container.html#ae7249d785dd2341ab463d4adfe0ed477", null ],
      [ "_notifyParent", "class_ogre_1_1_overlay_container.html#ad000b908177f17d14f1756bda718b8af", null ],
      [ "_updateRenderQueue", "class_ogre_1_1_overlay_container.html#aa8613e6cafc8e7ad8153e2dd33112d29", null ],
      [ "isContainer", "class_ogre_1_1_overlay_container.html#a732eb88fb222d0dc4429f4f0ec1d3595", null ],
      [ "isChildrenProcessEvents", "class_ogre_1_1_overlay_container.html#a741d3800b0b91697befa270b2da1e660", null ],
      [ "setChildrenProcessEvents", "class_ogre_1_1_overlay_container.html#acc3dbfd57c14ce83efcc89c22ef621b7", null ],
      [ "findElementAt", "class_ogre_1_1_overlay_container.html#ac422c04034704c90089308566075c273", null ],
      [ "copyFromTemplate", "class_ogre_1_1_overlay_container.html#a28f1f43785c7b8a4360926cb8c8ea09d", null ],
      [ "clone", "class_ogre_1_1_overlay_container.html#a12d0c2e4f1836f137f16370a5cc0f213", null ]
    ] ],
    [ "Ogre::OverlayElement", "class_ogre_1_1_overlay_element.html", [
      [ "OverlayElement", "class_ogre_1_1_overlay_element.html#adcc36fbc7c77c562cd66ec301cf1f889", null ],
      [ "~OverlayElement", "class_ogre_1_1_overlay_element.html#a7b9d2d08def8d7b5f33d36382db10d53", null ],
      [ "initialise", "class_ogre_1_1_overlay_element.html#a6226080248f5cf285a21b3996e845564", null ],
      [ "_releaseManualHardwareResources", "class_ogre_1_1_overlay_element.html#a02a099eba37c9f0f0700919535af0821", null ],
      [ "_restoreManualHardwareResources", "class_ogre_1_1_overlay_element.html#a581e6d515f04ce71f410711e828c3786", null ],
      [ "getName", "class_ogre_1_1_overlay_element.html#ae62c5ec2644bb045002b6bde8143a57f", null ],
      [ "show", "class_ogre_1_1_overlay_element.html#aa9bd185b0608279de2a0f89df7354cc1", null ],
      [ "hide", "class_ogre_1_1_overlay_element.html#abbacb24889857274550ad5241e0b2fbd", null ],
      [ "setVisible", "class_ogre_1_1_overlay_element.html#a4a8694d68fc244460eb91d213dfbeeba", null ],
      [ "isVisible", "class_ogre_1_1_overlay_element.html#a623e4aa0f508e2079edc11bf8917b070", null ],
      [ "isEnabled", "class_ogre_1_1_overlay_element.html#a84d6b68f81eebf46e42201d9a8a510ec", null ],
      [ "setEnabled", "class_ogre_1_1_overlay_element.html#a872ee4c823f00d1fd210af8230139e60", null ],
      [ "setDimensions", "class_ogre_1_1_overlay_element.html#a4e88f177d868c60525d6905a40d786db", null ],
      [ "setPosition", "class_ogre_1_1_overlay_element.html#a1e819a321a51a47238428307510559b7", null ],
      [ "setWidth", "class_ogre_1_1_overlay_element.html#a536908a4cdb6c35077dddbde9dda384b", null ],
      [ "getWidth", "class_ogre_1_1_overlay_element.html#a14e63d4c3d587b01ea94904a9e4d1c6b", null ],
      [ "setHeight", "class_ogre_1_1_overlay_element.html#a8fde301c55f7eb5b89333bffceaab32d", null ],
      [ "getHeight", "class_ogre_1_1_overlay_element.html#a1fff3e0b4ad1470a0cb25a73779d3291", null ],
      [ "setLeft", "class_ogre_1_1_overlay_element.html#ae7b546ce6736b50bdcd5807d98cf156b", null ],
      [ "getLeft", "class_ogre_1_1_overlay_element.html#aaf5fe0e1b686d33d2ecc7cb4b0569c80", null ],
      [ "setTop", "class_ogre_1_1_overlay_element.html#a4e79181c0b92ef6a7ee05a558e4784aa", null ],
      [ "getTop", "class_ogre_1_1_overlay_element.html#ae88216e2bab2a230b25cc8341981a6c1", null ],
      [ "_getLeft", "class_ogre_1_1_overlay_element.html#afd5bad2f48558fedb9d76f5547214903", null ],
      [ "_getTop", "class_ogre_1_1_overlay_element.html#a749d499624e7358cf1ac1d2d9bc90cf1", null ],
      [ "_getWidth", "class_ogre_1_1_overlay_element.html#a6f748e91dac18f0fdd80c97422d048c0", null ],
      [ "_getHeight", "class_ogre_1_1_overlay_element.html#ac8b8dd7b643fe7fa5b1e31bb0a0d570d", null ],
      [ "_setLeft", "class_ogre_1_1_overlay_element.html#a56d279033055d57e7872d00fea0a13e8", null ],
      [ "_setTop", "class_ogre_1_1_overlay_element.html#a1d18a26a0680bd724220ea282722d48c", null ],
      [ "_setWidth", "class_ogre_1_1_overlay_element.html#a65b2d7026e7e1a966f346d0500047989", null ],
      [ "_setHeight", "class_ogre_1_1_overlay_element.html#af4378d361e04e03e1ca8c63c73e53fc4", null ],
      [ "_setPosition", "class_ogre_1_1_overlay_element.html#a0984444e5ea957fea4880a8a2855e5d3", null ],
      [ "_setDimensions", "class_ogre_1_1_overlay_element.html#a7379d47f6b4ece51964f992cfa29fddb", null ],
      [ "getMaterialName", "class_ogre_1_1_overlay_element.html#a843f1e0087dd1aa948c7dd72594c9bdd", null ],
      [ "setMaterial", "class_ogre_1_1_overlay_element.html#a1548c9c20d0c4e4ff2c73590681dbddb", null ],
      [ "setMaterialName", "class_ogre_1_1_overlay_element.html#a5e792a41e37dd3c37cc3634cdc078ba2", null ],
      [ "getMaterial", "class_ogre_1_1_overlay_element.html#a7402a6bf264dd6620676cb3ffa2c350f", null ],
      [ "getWorldTransforms", "class_ogre_1_1_overlay_element.html#a1731bd728cad9066714db6f2b9e67aeb", null ],
      [ "_positionsOutOfDate", "class_ogre_1_1_overlay_element.html#a332f2ee98117ef701d8db7cc194a8f7d", null ],
      [ "_update", "class_ogre_1_1_overlay_element.html#ac2ac7daa6c0d03c72800fdde69c1636f", null ],
      [ "_updateFromParent", "class_ogre_1_1_overlay_element.html#a98050c3c2f7e3bf91769e9f98c203e64", null ],
      [ "_notifyParent", "class_ogre_1_1_overlay_element.html#a30ed52ccd1e7911239a0cd0209ca5f09", null ],
      [ "_getDerivedLeft", "class_ogre_1_1_overlay_element.html#abbb23a245b83f33926222206f81f7496", null ],
      [ "_getDerivedTop", "class_ogre_1_1_overlay_element.html#a149ed9dba547535540a515c0936cc1f2", null ],
      [ "_getRelativeWidth", "class_ogre_1_1_overlay_element.html#ad10ec98d6f8dd0906cb42f0f0b75eb8a", null ],
      [ "_getRelativeHeight", "class_ogre_1_1_overlay_element.html#a99536a748f2b9518ee323ca15bd80832", null ],
      [ "_getClippingRegion", "class_ogre_1_1_overlay_element.html#a97b633566faac55256ad2bfe1dc3ae43", null ],
      [ "_notifyZOrder", "class_ogre_1_1_overlay_element.html#a712333ce516ee70e1ad7e72fd4bf0336", null ],
      [ "_notifyWorldTransforms", "class_ogre_1_1_overlay_element.html#aee3b76c1c274a0995437e3e4bf095674", null ],
      [ "_notifyViewport", "class_ogre_1_1_overlay_element.html#a6affb58cf2e01ef086baf8ba49ea0fe5", null ],
      [ "_updateRenderQueue", "class_ogre_1_1_overlay_element.html#a278c8fdde2e52a5851bbd308cf3e6180", null ],
      [ "visitRenderables", "class_ogre_1_1_overlay_element.html#af15092ccb2db4413a5d5a74f02ca5dfd", null ],
      [ "getTypeName", "class_ogre_1_1_overlay_element.html#a1c194c450499ca4022e2debe00f33c84", null ],
      [ "setCaption", "class_ogre_1_1_overlay_element.html#abcb1a77f5c2ed706e8374b9aa9ae8c90", null ],
      [ "getCaption", "class_ogre_1_1_overlay_element.html#a815145efbdb6bcd0eeba982a54b4611f", null ],
      [ "setColour", "class_ogre_1_1_overlay_element.html#a2a7bfb2c2dea0e1c13ce51d102967f61", null ],
      [ "getColour", "class_ogre_1_1_overlay_element.html#a51b34483481b497f50956980de3799d0", null ],
      [ "setMetricsMode", "class_ogre_1_1_overlay_element.html#aaced65311a9f2256254b63f7846340a9", null ],
      [ "getMetricsMode", "class_ogre_1_1_overlay_element.html#a67ac95a6f10a46cd4befb9f0e84482d9", null ],
      [ "setHorizontalAlignment", "class_ogre_1_1_overlay_element.html#a35178b40251066c1fd27d6573603638c", null ],
      [ "getHorizontalAlignment", "class_ogre_1_1_overlay_element.html#a37d63f0e97b27e41229ecfaf04fbdc08", null ],
      [ "setVerticalAlignment", "class_ogre_1_1_overlay_element.html#ad8950ca2d32913491c5064f3b5fffba9", null ],
      [ "getVerticalAlignment", "class_ogre_1_1_overlay_element.html#a5b2cabc4fd6f8152c608394c5387fa16", null ],
      [ "contains", "class_ogre_1_1_overlay_element.html#aa6e49822c99b847fe7e5eb7b3bbc7035", null ],
      [ "findElementAt", "class_ogre_1_1_overlay_element.html#ab94c4fb534b9a435d542c7d216078089", null ],
      [ "isContainer", "class_ogre_1_1_overlay_element.html#af7bea868b91b54dd2ea9a2df3a96e2e0", null ],
      [ "isKeyEnabled", "class_ogre_1_1_overlay_element.html#a74d4bfd771df0fedfc37fd79d968141d", null ],
      [ "isCloneable", "class_ogre_1_1_overlay_element.html#a70ca6fec491ea9a7b0d25433935a36d7", null ],
      [ "setCloneable", "class_ogre_1_1_overlay_element.html#ab1180533d09933a92220e05129733978", null ],
      [ "getParent", "class_ogre_1_1_overlay_element.html#acf9618b92ff9785dd014f1004c9b342e", null ],
      [ "_setParent", "class_ogre_1_1_overlay_element.html#a950a51f806779b3ae50adc1cb05fff95", null ],
      [ "getZOrder", "class_ogre_1_1_overlay_element.html#ad0eb53760ccf63b90ec10739a6ca0733", null ],
      [ "getSquaredViewDepth", "class_ogre_1_1_overlay_element.html#afb350080df6f379e5a8dc23a13a86b22", null ],
      [ "getLights", "class_ogre_1_1_overlay_element.html#aca7c341c1cea314dbcf0f09c4dff378f", null ],
      [ "copyFromTemplate", "class_ogre_1_1_overlay_element.html#acdc6b75cd6f309b8af62a9e70e1e6a20", null ],
      [ "clone", "class_ogre_1_1_overlay_element.html#a1274fa3a3ccf02330d4012de4490cf5e", null ],
      [ "DEFAULT_RESOURCE_GROUP", "class_ogre_1_1_overlay_element.html#af7360f8bd59d3ffdefcaed91769b17dd", null ]
    ] ],
    [ "Ogre::OverlayElementFactory", "class_ogre_1_1_overlay_element_factory.html", [
      [ "~OverlayElementFactory", "class_ogre_1_1_overlay_element_factory.html#a1f58e18cf969c8ebbf5a40df93e744f0", null ],
      [ "createOverlayElement", "class_ogre_1_1_overlay_element_factory.html#aeefc52394fa50f9be0967ec718c04382", null ],
      [ "destroyOverlayElement", "class_ogre_1_1_overlay_element_factory.html#a72387fe84a4dc4e87d7ab1cfeaaf73b6", null ],
      [ "getTypeName", "class_ogre_1_1_overlay_element_factory.html#afbdc6f99366352734586546613007da4", null ]
    ] ],
    [ "Ogre::OverlayManager", "class_ogre_1_1_overlay_manager.html", [
      [ "OverlayMap", "class_ogre_1_1_overlay_manager.html#a1def2dea3aa2479b850b699c2c73e025", null ],
      [ "ElementMap", "class_ogre_1_1_overlay_manager.html#a96a3fbe3bce8a70cbedd1b6705106cdd", null ],
      [ "FactoryMap", "class_ogre_1_1_overlay_manager.html#a47343d4ae891d8e1bf676c8c39104be4", null ],
      [ "OverlayMapIterator", "class_ogre_1_1_overlay_manager.html#a1d38898d1d08e945f186e2043444588d", null ],
      [ "OverlayManager", "class_ogre_1_1_overlay_manager.html#af2079b7b61e8df96d67f852aa6de7dac", null ],
      [ "~OverlayManager", "class_ogre_1_1_overlay_manager.html#a1cd64a87fb0ab23c3163af27989d8005", null ],
      [ "_releaseManualHardwareResources", "class_ogre_1_1_overlay_manager.html#a6f4c5ea14ae145edcdac623ea1c80f8e", null ],
      [ "_restoreManualHardwareResources", "class_ogre_1_1_overlay_manager.html#a4b74d07681568ba1ab0f891e07338aee", null ],
      [ "getScriptPatterns", "class_ogre_1_1_overlay_manager.html#a7e683f116824f797a437fa4f6dcdf529", null ],
      [ "parseScript", "class_ogre_1_1_overlay_manager.html#ae4debd1d5a138ddd1fea2d290bb5ce6c", null ],
      [ "getLoadingOrder", "class_ogre_1_1_overlay_manager.html#a7a7c9e28fa16d9b859e7f886b986f91e", null ],
      [ "addOverlay", "class_ogre_1_1_overlay_manager.html#aa79a08ba546e1670b49b318a4e28317b", null ],
      [ "create", "class_ogre_1_1_overlay_manager.html#a52f692050acf9838e4923276773bdf6e", null ],
      [ "getByName", "class_ogre_1_1_overlay_manager.html#a451295cc3fa8ee496aaddc372592c7fd", null ],
      [ "destroy", "class_ogre_1_1_overlay_manager.html#a490ccc24cd1eda279e0bf349273598e8", null ],
      [ "destroy", "class_ogre_1_1_overlay_manager.html#a9bb21fa10ec0c6e77b5eff13a9dccbe8", null ],
      [ "destroyAll", "class_ogre_1_1_overlay_manager.html#ae3677704d31fd65c47e8f1f27c38fae3", null ],
      [ "getOverlayIterator", "class_ogre_1_1_overlay_manager.html#a140ab8e9bc0e307c28b335406e45cef6", null ],
      [ "_queueOverlaysForRendering", "class_ogre_1_1_overlay_manager.html#a1a73ce8b360346d2174a7be61d2ead7d", null ],
      [ "getViewportHeight", "class_ogre_1_1_overlay_manager.html#add848786d9b85650df1655b4918d583f", null ],
      [ "getViewportWidth", "class_ogre_1_1_overlay_manager.html#a13e54818ef3e17df61103a4aecfc801e", null ],
      [ "getViewportAspectRatio", "class_ogre_1_1_overlay_manager.html#abe6a61b3eb7d445f0024d031e2783a11", null ],
      [ "setPixelRatio", "class_ogre_1_1_overlay_manager.html#a1f43bd165903937c9e5c3ceb4a569676", null ],
      [ "getPixelRatio", "class_ogre_1_1_overlay_manager.html#aab503bb19f21fe142758ddb8de9102c9", null ],
      [ "createOverlayElement", "class_ogre_1_1_overlay_manager.html#a57ec828532529f96ec6bc9d0e54fd5f5", null ],
      [ "getOverlayElement", "class_ogre_1_1_overlay_manager.html#add490259e2ab9b8532279e37726df1ee", null ],
      [ "hasOverlayElement", "class_ogre_1_1_overlay_manager.html#a6f44bb3a42b0cd48de18e2a47e59783d", null ],
      [ "destroyOverlayElement", "class_ogre_1_1_overlay_manager.html#aa4f2e6c62b24aa312daa278aa67a9261", null ],
      [ "destroyOverlayElement", "class_ogre_1_1_overlay_manager.html#a75cb894f367b6d19d22745c41c2268ef", null ],
      [ "destroyAllOverlayElements", "class_ogre_1_1_overlay_manager.html#aa88cb419bd4f9f95486485e8c3bc4ddf", null ],
      [ "addOverlayElementFactory", "class_ogre_1_1_overlay_manager.html#a8d755456d249ff80d469e9c3944d22ed", null ],
      [ "getOverlayElementFactoryMap", "class_ogre_1_1_overlay_manager.html#a146362b54f4e7983deb8a7f15a9bd001", null ],
      [ "createOverlayElementFromTemplate", "class_ogre_1_1_overlay_manager.html#a48c2efea42ce3e6c19ad6e2428bd4419", null ],
      [ "cloneOverlayElementFromTemplate", "class_ogre_1_1_overlay_manager.html#a0a17d17cbf637f010654c32db043fd63", null ],
      [ "createOverlayElementFromFactory", "class_ogre_1_1_overlay_manager.html#a45e1b29938ebcd5308c8e3492efa7445", null ],
      [ "getSingleton", "class_ogre_1_1_overlay_manager.html#ab2e4471ac74f2307680d9fd1057865f8", null ],
      [ "getSingletonPtr", "class_ogre_1_1_overlay_manager.html#a656f35aa81bc8fdcddb0c675e7ab2dd7", null ]
    ] ],
    [ "Ogre::OverlayProfileSessionListener", "class_ogre_1_1_overlay_profile_session_listener.html", [
      [ "DisplayMode", "group___overlays.html#ga8eaf5c62bec83cede8f1608d998bad1a", [
        [ "DISPLAY_PERCENTAGE", "group___overlays.html#gga8eaf5c62bec83cede8f1608d998bad1aa5b3ca2d76f173ddbf852adef988cf514", null ],
        [ "DISPLAY_MILLISECONDS", "group___overlays.html#gga8eaf5c62bec83cede8f1608d998bad1aa20d40e6172289b29a23c04d4de06d864", null ]
      ] ],
      [ "OverlayProfileSessionListener", "group___overlays.html#ga0e01e25edada5ead1e83defaa33a36d5", null ],
      [ "~OverlayProfileSessionListener", "group___overlays.html#gaebe4b67ba05a64874b143fd0725fa3de", null ],
      [ "initializeSession", "group___overlays.html#ga4023d2f3b07a5c6e81bddfe5f5d02854", null ],
      [ "finializeSession", "group___overlays.html#ga762285257a6ca6d3cd87b14a356d3293", null ],
      [ "displayResults", "group___overlays.html#ga6f9ce6a1cb07def7542011e616c2047b", null ],
      [ "changeEnableState", "group___overlays.html#ga923def772455064a18eaa248c04627a0", null ],
      [ "setOverlayDimensions", "group___overlays.html#gae6499766c023a82604089b5709bd5766", null ],
      [ "setOverlayPosition", "group___overlays.html#gae5f061c130a4b6d0e77b2194c3c7752a", null ],
      [ "getOverlayWidth", "group___overlays.html#ga4e715f58918a24d710325fc60c6d9f09", null ],
      [ "getOverlayHeight", "group___overlays.html#ga1071609968c77da817a2e7cad817bed7", null ],
      [ "getOverlayLeft", "group___overlays.html#gab78db047c2c4e618f36ff84b5430c352", null ],
      [ "getOverlayTop", "group___overlays.html#ga5e2444c3553a432e0403d6a7da6e39f1", null ],
      [ "setDisplayMode", "group___overlays.html#gac129b7c4d9396dfd36587baae858387e", null ],
      [ "getDisplayMode", "group___overlays.html#ga945723ccd02d3d9592903813e27d5e94", null ]
    ] ],
    [ "Ogre::OverlaySystem", "class_ogre_1_1_overlay_system.html", [
      [ "OverlaySystem", "group___overlays.html#gacd5c773075a7591f717fb2382df9a829", null ],
      [ "~OverlaySystem", "group___overlays.html#gad399638657ead9815683c02bc7fdf149", null ],
      [ "preRenderQueues", "group___overlays.html#gaf6fb54d4dea385f958844f3ab8947bd0", null ],
      [ "eventOccurred", "group___overlays.html#ga449a8ac2b301e045c0ceec32a2289f8b", null ],
      [ "getSingleton", "group___overlays.html#gaffcea382193d1edf6b21703f298d35ce", null ],
      [ "getSingletonPtr", "group___overlays.html#ga7945d431719c60ccb40d356e268f5558", null ]
    ] ],
    [ "Ogre::PanelOverlayElement", "class_ogre_1_1_panel_overlay_element.html", [
      [ "PanelOverlayElement", "class_ogre_1_1_panel_overlay_element.html#a8c1555d05bf15c36606c441279e8465b", null ],
      [ "~PanelOverlayElement", "class_ogre_1_1_panel_overlay_element.html#ab7898dddb9d637fbbf8c90d9bc45f37e", null ],
      [ "initialise", "class_ogre_1_1_panel_overlay_element.html#a10bb6004a99b131eb10e025f5d1bd952", null ],
      [ "_releaseManualHardwareResources", "class_ogre_1_1_panel_overlay_element.html#a1a75d60e71d416d174696644d5dba8ff", null ],
      [ "_restoreManualHardwareResources", "class_ogre_1_1_panel_overlay_element.html#a6ce636b99f0dd37ba3b6de8dd39422f3", null ],
      [ "setTiling", "class_ogre_1_1_panel_overlay_element.html#a393ea3e5d74c4b93dc9bcf364e1b52e0", null ],
      [ "getTileX", "class_ogre_1_1_panel_overlay_element.html#a2b017beabc9a6db3e556f92eb207a565", null ],
      [ "getTileY", "class_ogre_1_1_panel_overlay_element.html#a1ae2c9bb50399abf5752ab26c171d8b3", null ],
      [ "setUV", "class_ogre_1_1_panel_overlay_element.html#a1d6627fa3a9690df18fbd0010ad161b7", null ],
      [ "getUV", "class_ogre_1_1_panel_overlay_element.html#a25a338c0ecebf4057fb0f1a60c47f22b", null ],
      [ "setTransparent", "class_ogre_1_1_panel_overlay_element.html#a9db0b968a93e9db1875f91c7784949d9", null ],
      [ "isTransparent", "class_ogre_1_1_panel_overlay_element.html#a321316349fac8be33a25b27b300b42c5", null ],
      [ "getTypeName", "class_ogre_1_1_panel_overlay_element.html#a38f672956cbf073d900f4c99b72cbf2e", null ],
      [ "getRenderOperation", "class_ogre_1_1_panel_overlay_element.html#a8ebabecbb8999bda5cdd1bb0b0521b2d", null ],
      [ "_updateRenderQueue", "class_ogre_1_1_panel_overlay_element.html#a8de2ab1a4cc7887c2959049006f51890", null ]
    ] ],
    [ "Ogre::TextAreaOverlayElement", "class_ogre_1_1_text_area_overlay_element.html", [
      [ "Alignment", "class_ogre_1_1_text_area_overlay_element.html#a10447c4f63a1ea3b9084d32518dd7620", [
        [ "Left", "class_ogre_1_1_text_area_overlay_element.html#a10447c4f63a1ea3b9084d32518dd7620aa2de28cc541a4e31b1af35e0bc97f6e3", null ],
        [ "Right", "class_ogre_1_1_text_area_overlay_element.html#a10447c4f63a1ea3b9084d32518dd7620a224b24e02502ea0d67ec607db7117f86", null ],
        [ "Center", "class_ogre_1_1_text_area_overlay_element.html#a10447c4f63a1ea3b9084d32518dd7620a7ad07bf977d410148895edaeab788c8c", null ]
      ] ],
      [ "TextAreaOverlayElement", "class_ogre_1_1_text_area_overlay_element.html#a5b255cf4e489d0a866411f5c946f6a7b", null ],
      [ "~TextAreaOverlayElement", "class_ogre_1_1_text_area_overlay_element.html#a21eaf0db5316ed999f314cde27a7802e", null ],
      [ "initialise", "class_ogre_1_1_text_area_overlay_element.html#a5327834ccac44701485e3270b227c114", null ],
      [ "_releaseManualHardwareResources", "class_ogre_1_1_text_area_overlay_element.html#a396326cc2b6179111145fc2dfa2469cb", null ],
      [ "_restoreManualHardwareResources", "class_ogre_1_1_text_area_overlay_element.html#a74ae6ab5d6b04902df7157befe22d559", null ],
      [ "setCaption", "class_ogre_1_1_text_area_overlay_element.html#a32fdba4e3f3c7497527a88bfbbf40826", null ],
      [ "setCharHeight", "class_ogre_1_1_text_area_overlay_element.html#a0853972924f45c0e44f6d879dffcd5c1", null ],
      [ "getCharHeight", "class_ogre_1_1_text_area_overlay_element.html#a399d5f2c4499bd02fd0dbe573861b8f5", null ],
      [ "setSpaceWidth", "class_ogre_1_1_text_area_overlay_element.html#af69d715288b94d320e4ed3ea99fd68a3", null ],
      [ "getSpaceWidth", "class_ogre_1_1_text_area_overlay_element.html#a001ceb10a8dad09a37aa1a5b45d4db94", null ],
      [ "setFontName", "class_ogre_1_1_text_area_overlay_element.html#a237c4c55246d69d47b23922e4f613e29", null ],
      [ "getFontName", "class_ogre_1_1_text_area_overlay_element.html#a056aeab209af1504c048e94049b568b1", null ],
      [ "getFont", "class_ogre_1_1_text_area_overlay_element.html#a7ec27f0c86c3f044c1709c4ab4c25183", null ],
      [ "getTypeName", "class_ogre_1_1_text_area_overlay_element.html#a32ac73bd5c5364206cbc375f417b4014", null ],
      [ "getMaterial", "class_ogre_1_1_text_area_overlay_element.html#adf142c9b6918e7d655f4937828618f42", null ],
      [ "getRenderOperation", "class_ogre_1_1_text_area_overlay_element.html#a33fdca7d5368faa39dd94a360a80a6bb", null ],
      [ "setColour", "class_ogre_1_1_text_area_overlay_element.html#ac890db58eaa989235c479ea11102a246", null ],
      [ "getColour", "class_ogre_1_1_text_area_overlay_element.html#a89d9e045fca443f48ffd4eb003de89a1", null ],
      [ "setColourBottom", "class_ogre_1_1_text_area_overlay_element.html#aeb5a40e72c6f7dc4c74217ecd390a6c6", null ],
      [ "getColourBottom", "class_ogre_1_1_text_area_overlay_element.html#a6a85cbc1e043c335825d2a7ce3fd819c", null ],
      [ "setColourTop", "class_ogre_1_1_text_area_overlay_element.html#a4e5756233afa12a3730a8fdfe2d3fe1a", null ],
      [ "getColourTop", "class_ogre_1_1_text_area_overlay_element.html#a8147fbef5897e9664921efe5f999989c", null ],
      [ "setAlignment", "class_ogre_1_1_text_area_overlay_element.html#a4bfa3788d8c187e446f2e8272960a1d8", null ],
      [ "getAlignment", "class_ogre_1_1_text_area_overlay_element.html#a250bbd11c9d31b49910b7decde060ed6", null ],
      [ "setMetricsMode", "class_ogre_1_1_text_area_overlay_element.html#a4a6210b456a05cc6c78836da35cf7095", null ],
      [ "_update", "class_ogre_1_1_text_area_overlay_element.html#a083b7a30ee82a41bbea7a521576c5c5f", null ]
    ] ],
    [ "Ogre::FontPtr", "group___overlays.html#ga6fc186106cde55e3a7b867798fe28e89", null ],
    [ "Ogre::DisplayString", "group___overlays.html#ga12ec415f18ba8932c5e0bfa49036fc5b", null ],
    [ "Ogre::FontType", "group___overlays.html#ga7d22ba70debe31488cdd62c5dc307ce9", [
      [ "Ogre::FT_TRUETYPE", "group___overlays.html#gga7d22ba70debe31488cdd62c5dc307ce9a3185a44789d385148728f61682e74354", null ],
      [ "Ogre::FT_IMAGE", "group___overlays.html#gga7d22ba70debe31488cdd62c5dc307ce9ac5c0824a886f1c3946159c1303397c68", null ]
    ] ],
    [ "Ogre::GuiMetricsMode", "group___overlays.html#gaa7655e44eacdfd45427ff35bde855f36", [
      [ "Ogre::GMM_RELATIVE", "group___overlays.html#ggaa7655e44eacdfd45427ff35bde855f36ae7050335374e46745e3c956b940ace9d", null ],
      [ "Ogre::GMM_PIXELS", "group___overlays.html#ggaa7655e44eacdfd45427ff35bde855f36a1995cd35704cb8894f502f135b46309d", null ],
      [ "Ogre::GMM_RELATIVE_ASPECT_ADJUSTED", "group___overlays.html#ggaa7655e44eacdfd45427ff35bde855f36a2664ae89e7bd4079392f7feff26b3597", null ]
    ] ],
    [ "Ogre::GuiHorizontalAlignment", "group___overlays.html#ga3396780cdb2d731aa5e4389148bdc5f3", [
      [ "Ogre::GHA_LEFT", "group___overlays.html#gga3396780cdb2d731aa5e4389148bdc5f3a69adf8fd8fa9b00e1c4eba735d0a17cb", null ],
      [ "Ogre::GHA_CENTER", "group___overlays.html#gga3396780cdb2d731aa5e4389148bdc5f3a64a73804088bb89e7243a14874a457cd", null ],
      [ "Ogre::GHA_RIGHT", "group___overlays.html#gga3396780cdb2d731aa5e4389148bdc5f3a270f18cf07dbe4e75e1b790d02924205", null ]
    ] ],
    [ "Ogre::GuiVerticalAlignment", "group___overlays.html#gab0815ab90a2d9635695ec7e20e6c372e", [
      [ "Ogre::GVA_TOP", "group___overlays.html#ggab0815ab90a2d9635695ec7e20e6c372eabd89b9daa45f558ebf40181220421c2b", null ],
      [ "Ogre::GVA_CENTER", "group___overlays.html#ggab0815ab90a2d9635695ec7e20e6c372ea730c870b4637187418842a7545a8d40b", null ],
      [ "Ogre::GVA_BOTTOM", "group___overlays.html#ggab0815ab90a2d9635695ec7e20e6c372eae1858486046629fda36e43b0bfece87a", null ]
    ] ],
    [ "Ogre::OverlayProfileSessionListener::DisplayMode", "group___overlays.html#ga8eaf5c62bec83cede8f1608d998bad1a", [
      [ "Ogre::OverlayProfileSessionListener::DISPLAY_PERCENTAGE", "group___overlays.html#gga8eaf5c62bec83cede8f1608d998bad1aa5b3ca2d76f173ddbf852adef988cf514", null ],
      [ "Ogre::OverlayProfileSessionListener::DISPLAY_MILLISECONDS", "group___overlays.html#gga8eaf5c62bec83cede8f1608d998bad1aa20d40e6172289b29a23c04d4de06d864", null ]
    ] ],
    [ "Ogre::OverlayProfileSessionListener::DISPLAY_PERCENTAGE", "group___overlays.html#gga8eaf5c62bec83cede8f1608d998bad1aa5b3ca2d76f173ddbf852adef988cf514", null ],
    [ "Ogre::OverlayProfileSessionListener::DISPLAY_MILLISECONDS", "group___overlays.html#gga8eaf5c62bec83cede8f1608d998bad1aa20d40e6172289b29a23c04d4de06d864", null ],
    [ "Ogre::utftoc32", "group___overlays.html#gac0f6dfac6ee7cc190e3dcde1f7b58f60", null ],
    [ "Ogre::OverlayProfileSessionListener::OverlayProfileSessionListener", "group___overlays.html#ga0e01e25edada5ead1e83defaa33a36d5", null ],
    [ "Ogre::OverlayProfileSessionListener::~OverlayProfileSessionListener", "group___overlays.html#gaebe4b67ba05a64874b143fd0725fa3de", null ],
    [ "Ogre::OverlayProfileSessionListener::initializeSession", "group___overlays.html#ga4023d2f3b07a5c6e81bddfe5f5d02854", null ],
    [ "Ogre::OverlayProfileSessionListener::finializeSession", "group___overlays.html#ga762285257a6ca6d3cd87b14a356d3293", null ],
    [ "Ogre::OverlayProfileSessionListener::displayResults", "group___overlays.html#ga6f9ce6a1cb07def7542011e616c2047b", null ],
    [ "Ogre::OverlayProfileSessionListener::changeEnableState", "group___overlays.html#ga923def772455064a18eaa248c04627a0", null ],
    [ "Ogre::OverlayProfileSessionListener::setOverlayDimensions", "group___overlays.html#gae6499766c023a82604089b5709bd5766", null ],
    [ "Ogre::OverlayProfileSessionListener::setOverlayPosition", "group___overlays.html#gae5f061c130a4b6d0e77b2194c3c7752a", null ],
    [ "Ogre::OverlayProfileSessionListener::getOverlayWidth", "group___overlays.html#ga4e715f58918a24d710325fc60c6d9f09", null ],
    [ "Ogre::OverlayProfileSessionListener::getOverlayHeight", "group___overlays.html#ga1071609968c77da817a2e7cad817bed7", null ],
    [ "Ogre::OverlayProfileSessionListener::getOverlayLeft", "group___overlays.html#gab78db047c2c4e618f36ff84b5430c352", null ],
    [ "Ogre::OverlayProfileSessionListener::getOverlayTop", "group___overlays.html#ga5e2444c3553a432e0403d6a7da6e39f1", null ],
    [ "Ogre::OverlayProfileSessionListener::setDisplayMode", "group___overlays.html#gac129b7c4d9396dfd36587baae858387e", null ],
    [ "Ogre::OverlayProfileSessionListener::getDisplayMode", "group___overlays.html#ga945723ccd02d3d9592903813e27d5e94", null ],
    [ "Ogre::OverlaySystem::OverlaySystem", "group___overlays.html#gacd5c773075a7591f717fb2382df9a829", null ],
    [ "Ogre::OverlaySystem::~OverlaySystem", "group___overlays.html#gad399638657ead9815683c02bc7fdf149", null ],
    [ "Ogre::OverlaySystem::preRenderQueues", "group___overlays.html#gaf6fb54d4dea385f958844f3ab8947bd0", null ],
    [ "Ogre::OverlaySystem::eventOccurred", "group___overlays.html#ga449a8ac2b301e045c0ceec32a2289f8b", null ],
    [ "Ogre::OverlaySystem::getSingleton", "group___overlays.html#gaffcea382193d1edf6b21703f298d35ce", null ],
    [ "Ogre::OverlaySystem::getSingletonPtr", "group___overlays.html#ga7945d431719c60ccb40d356e268f5558", null ]
];